@@ -1,4 +1,5 @@
-from botocove.cove_decorator import CoveOutput, cove
+from botocove.cove_decorator import cove
 from botocove.cove_session import CoveSession
+from botocove.cove_types import CoveOutput
 
 __all__ = ["cove", "CoveSession", "CoveOutput"]
